Description: Lists all of the available service-specific resources, actions, and condition keys that can be used in IAM policies to control access to Amazon Rekognition.

Actions, resources, and condition keys for Amazon Rekognition - Service Authorization Reference

# Actions, resources, and condition keys for Amazon Rekognition

Amazon Rekognition (service prefix: `rekognition` ) provides the following service-specific resources, actions, and condition context keys for use in IAM permission policies.

References:

- Learn how to configure this service .

- View a list of the API operations available for this service .

- Learn how to secure this service and its resources by using IAM permission policies.

###### Topics

- Actions defined by Amazon Rekognition
- Resource types defined by Amazon Rekognition
- Condition keys for Amazon Rekognition

## Actions defined by Amazon Rekognition

You can specify the following actions in the `Action` element of an IAM policy statement. Use policies to grant permissions to perform an operation in AWS. When you use an action in a policy, you usually allow or deny access to the API operation or CLI command with the same name. However, in some cases, a single action controls access to more than one operation. Alternatively, some operations require several different actions.

The Resource types column of the Actions table indicates whether each action supports resource-level permissions. If there is no value for this column, you must specify all resources ("*") to which the policy applies in the `Resource` element of your policy statement. If the column includes a resource type, then you can specify an ARN of that type in a statement with that action. If the action has one or more required resources, the caller must have permission to use the action with those resources. Required resources are indicated in the table with an asterisk (*). If you limit resource access with the `Resource` element in an IAM policy, you must include an ARN or pattern for each required resource type. Some actions support multiple resource types. If the resource type is optional (not indicated as required), then you can choose to use one of the optional resource types.

The Condition keys column of the Actions table includes keys that you can specify in a policy statement's `Condition` element. For more information on the condition keys that are associated with resources for the service, see the Condition keys column of the Resource types table.

###### Note

Resource condition keys are listed in the Resource types table. You can find a link to the resource type that applies to an action in the Resource types (*required) column of the Actions table. The resource type in the Resource types table includes the Condition keys column, which are the resource condition keys that apply to an action in the Actions table.

For details about the columns in the following table, see Actions table .

Actions | Description | Access level | Resource types (*required) | Condition keys | Dependent actions
--- | --- | --- | --- | --- | ---
AssociateFaces | Grants permission to associate multiple individual faces with a single user | Write | collection* |  |
CompareFaces | Grants permission to compare faces in the source input image with each face detected in the target input image | Read |  |  |
CopyProjectVersion | Grants permission to copy an existing model version to a new model version | Write | project* |  |
projectversion* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateCollection | Grants permission to create a collection in an AWS Region | Write | collection* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateDataset | Grants permission to create a new Amazon Rekognition Custom Labels dataset | Write | project* |  |
CreateFaceLivenessSession | Grants permission to create a face liveness session | Write |  |  |
CreateProject | Grants permission to create an Amazon Rekognition Custom Labels project | Write | project* |  |
CreateProjectVersion | Grants permission to begin training a new version of a model | Write | project* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateStreamProcessor | Grants permission to create an Amazon Rekognition stream processor | Write | collection* |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
CreateUser | Grants permission to create a new user in a collection using a unique user ID you provide | Write | collection* |  |
DeleteCollection | Grants permission to delete the specified collection | Write | collection* |  |
DeleteDataset | Grants permission to delete an existing Amazon Rekognition Custom Labels dataset | Write | dataset* |  |
DeleteFaces | Grants permission to delete faces from a collection | Write | collection* |  |
DeleteProject | Grants permission to delete a project | Write | project* |  |
DeleteProjectPolicy | Grants permission to delete a resource policy attached to a project | Write | project* |  |
DeleteProjectVersion | Grants permission to delete a model | Write | projectversion* |  |
DeleteStreamProcessor | Grants permission to delete the specified stream processor | Write | streamprocessor* |  |
DeleteUser | Grants permission to delete a user from a collection based on the provided user ID | Write | collection* |  |
DescribeCollection | Grants permission to read details about a collection | Read | collection* |  |
DescribeDataset | Grants permission to describe an Amazon Rekognition Custom Labels dataset | Read | dataset* |  |
DescribeProjectVersions | Grants permission to list the versions of a model in an Amazon Rekognition Custom Labels project | Read | project* |  |
DescribeProjects | Grants permission to list Amazon Rekognition Custom Labels projects | Read |  |  |
DescribeStreamProcessor | Grants permission to get information about the specified stream processor | Read | streamprocessor* |  |
DetectCustomLabels | Grants permission to detect custom labels in a supplied image | Read | projectversion* |  |
DetectFaces | Grants permission to detect human faces within an image provided as input | Read |  |  |
DetectLabels | Grants permission to detect instances of real-world labels within an image provided as input | Read |  |  |
DetectModerationLabels | Grants permission to detect moderation labels within the input image | Read | projectversion |  |
DetectProtectiveEquipment | Grants permission to detect Personal Protective Equipment in the input image | Read |  |  |
DetectText | Grants permission to detect text in the input image and convert it into machine-readable text | Read |  |  |
DisassociateFaces | Grants permission to remove the association between a user ID and a face ID | Write | collection* |  |
DistributeDatasetEntries | Grants permission to distribute the entries in a training dataset across the training dataset and the test dataset for a project | Write | dataset* |  |
GetCelebrityInfo | Grants permission to read the name, and additional information, of a celebrity | Read |  |  |
GetCelebrityRecognition | Grants permission to read the celebrity recognition results found in a stored video by an asynchronous celebrity recognition job | Read |  |  |
GetContentModeration | Grants permission to read the content moderation analysis results found in a stored video by an asynchronous content moderation job | Read |  |  |
GetFaceDetection | Grants permission to read the faces detection results found in a stored video by an asynchronous face detection job | Read |  |  |
GetFaceLivenessSessionResults | Grants permission to get results of a face liveness session | Read |  |  |
GetFaceSearch | Grants permission to read the matching collection faces found in a stored video by an asynchronous face search job | Read |  |  |
GetLabelDetection | Grants permission to read the label detected resuls found in a stored video by an asynchronous label detection job | Read |  |  |
GetMediaAnalysisJob | Grants permission to read the reference to job results in S3 and additional information about a media analysis job | Read |  |  |
GetPersonTracking | Grants permission to read the list of persons detected in a stored video by an asynchronous person tracking job | Read |  |  |
GetSegmentDetection | Grants permission to get the vdeo segments found in a stored video by an asynchronous segment detection job | Read |  |  |
GetTextDetection | Grants permission to get the text found in a stored video by an asynchronous text detection job | Read |  |  |
IndexFaces | Grants permission to update an existing collection with faces detected in the input image | Write | collection* |  |
ListCollections | Grants permission to read the collection Id's in your account | Read |  |  |
ListDatasetEntries | Grants permission to list the dataset entries in an existing Amazon Rekognition Custom Labels dataset | Read | dataset* |  |
ListDatasetLabels | Grants permission to list the labels in a dataset | Read | dataset* |  |
ListFaces | Grants permission to read metadata for faces in the specificed collection | Read | collection* |  |
ListMediaAnalysisJobs | Grants permission to read the list of media analysis jobs | Read |  |  |
ListProjectPolicies | Grants permission to list the resource policies attached to a project | Read | project* |  |
ListStreamProcessors | Grants permission to get a list of your stream processors | List | streamprocessor* |  |
ListTagsForResource | Grants permission to return a list of tags associated with a resource | Read | projectversion* |  |
ListUsers | Grants permission to list UserIds and the UserStatus | Read | collection* |  |
PutProjectPolicy | Grants permission to attach a resource policy to a project | Write | project* |  |
RecognizeCelebrities | Grants permission to detect celebrities in the input image | Read |  |  |
SearchFaces | Grants permission to search the specificed collection for the supplied face ID | Read | collection* |  |
SearchFacesByImage | Grants permission to search the specificed collection for the largest face in the input image | Read | collection* |  |
SearchUsers | Grants permission to search the specificed collection for user match result with given either face ID or user ID | Read | collection* |  |
SearchUsersByImage | Grants permission to search the specificed collection for user match result by using the largest face in the input image | Read | collection* |  |
StartCelebrityRecognition | Grants permission to start the asynchronous recognition of celebrities in a stored video | Write |  |  |
StartContentModeration | Grants permission to start asynchronous detection of explicit or suggestive adult content in a stored video | Write |  |  |
StartFaceDetection | Grants permission to start asynchronous detection of faces in a stored video | Write |  |  |
StartFaceLivenessSession | Grants permission to start streaming video for a face liveness session | Write |  |  |
StartFaceSearch | Grants permission to start an asynchronous search for faces in a collection that match the faces of persons detected in a stored video | Write | collection* |  |
StartLabelDetection | Grants permission to start asynchronous detection of labels in a stored video | Write |  |  |
StartMediaAnalysisJob | Grants permission to start a media analysis job | Write | projectversion |  |
StartPersonTracking | Grants permission to start the asynchronous tracking of persons in a stored video | Write |  |  |
StartProjectVersion | Grants permission to start running a model version | Write | projectversion* |  |
StartSegmentDetection | Grants permission to start the asynchronous detection of segments in a stored video | Write |  |  |
StartStreamProcessor | Grants permission to start running a stream processor | Write | streamprocessor* |  |
StartTextDetection | Grants permission to start the asynchronous detection of text in a stored video | Write |  |  |
StopProjectVersion | Grants permission to stop a running model version | Write | projectversion* |  |
StopStreamProcessor | Grants permission to stop a running stream processor | Write | streamprocessor* |  |
TagResource | Grants permission to add one or more tags to a resource | Tagging | collection |  |
projectversion |  |
streamprocessor |  |
| aws:RequestTag/${TagKey} aws:TagKeys |
UntagResource | Grants permission to remove one or more tags from a resource | Tagging | collection |  |
projectversion |  |
streamprocessor |  |
| aws:TagKeys |
UpdateDatasetEntries | Grants permission to add or update one or more JSON Lines (entries) in a dataset | Write | dataset* |  |
UpdateStreamProcessor | Grants permission to modify properties for a stream processor | Write | streamprocessor* |  |

## Resource types defined by Amazon Rekognition

The following resource types are defined by this service and can be used in the `Resource` element of IAM permission policy statements. Each action in the Actions table identifies the resource types that can be specified with that action. A resource type can also define which condition keys you can include in a policy. These keys are displayed in the last column of the Resource types table. For details about the columns in the following table, see Resource types table .

Resource types | ARN | Condition keys
--- | --- | ---
collection | `arn:$ { Partition}:rekognition:$ { Region}:$ { Account}:collection/$ { CollectionId}` | aws:ResourceTag/${TagKey}
streamprocessor | `arn:$ { Partition}:rekognition:$ { Region}:$ { Account}:streamprocessor/$ { StreamprocessorId}` | aws:ResourceTag/${TagKey}
project | `arn:$ { Partition}:rekognition:$ { Region}:$ { Account}:project/$ { ProjectName}/$ { CreationTimestamp}` |
projectversion | `arn:$ { Partition}:rekognition:$ { Region}:$ { Account}:project/$ { ProjectName}/version/$ { VersionName}/$ { CreationTimestamp}` | aws:ResourceTag/${TagKey}
dataset | `arn:$ { Partition}:rekognition:$ { Region}:$ { Account}:project/$ { ProjectName}/dataset/$ { DatasetType}/$ { CreationTimestamp}` |

## Condition keys for Amazon Rekognition

Amazon Rekognition defines the following condition keys that can be used in the `Condition` element of an IAM policy. You can use these keys to further refine the conditions under which the policy statement applies. For details about the columns in the following table, see Condition keys table .

To view the global condition keys that are available to all services, see Available global condition keys .

Condition keys | Description | Type
--- | --- | ---
aws:RequestTag/${TagKey} | Filters access by tags that are passed in the request | String
aws:ResourceTag/${TagKey} | Filters access by tags associated with the resource | String
aws:TagKeys | Filters access by tag keys that are passed in the request | ArrayOfString

Did this page help you? - Yes

Thanks for letting us know we're doing a good job!

If you've got a moment, please tell us what we did right so we can do more of it.

Did this page help you? - No

Thanks for letting us know this page needs work. We're sorry we let you down.

If you've got a moment, please tell us how we can make the documentation better.